@@ -47,6 +47,7 @@ class CheckBoxField(FieldElement, ReqInjectScriptMixin):
     def data(self, value):
         if value:
             self.input.attrs.append(('checked', ''))
+            self._data = value
 
 class DateField(FieldElement, ReqInjectScriptMixin):
     
@@ -88,6 +89,7 @@ class DateField(FieldElement, ReqInjectScriptMixin):
         # reset ui
         fm_date = datetime.strftime(value, self.py_format) if value else self.form_data
         self.input.attrs.append(('value', fm_date))
+        self._data = value
         
 class DateTimeField(FieldElement, ReqInjectScriptMixin):
     def __init__(self, name, required=False, disabled=False, readonly=False, placeholder=None, validators=None):
@@ -130,6 +132,7 @@ class DateTimeField(FieldElement, ReqInjectScriptMixin):
         # reset ui
         fm_date = datetime.strftime(value, self.py_format) if value else self.form_data
         self.input.attrs.append(('value', fm_date))
+        self._data = value
 
 class DropDownField(FieldElement, ReqInjectScriptMixin):
     inject_script = ValidProp(str)
@@ -173,6 +176,7 @@ class DropDownField(FieldElement, ReqInjectScriptMixin):
     def data(self, value):
         # reset ui
         value = value if value else self.form_data
+        self._data = value
         options = []
         if self.choices:
             # validate if choices are a list of tuple
@@ -189,6 +193,7 @@ class QueryDropDownField(FieldElement, ReqInjectScriptMixin):
     field_name = ValidProp(str)
     from_table = ValidProp(str)
     where = ValidProp(str)
+    order_by = ValidProp(str)
     additional_where = ValidProp(str)
     inject_script = ValidProp(str)
     
@@ -205,6 +210,7 @@ class QueryDropDownField(FieldElement, ReqInjectScriptMixin):
             field_name=None, 
             from_table=None, 
             where=None, 
+            order_by=None,
             additional_where=None, 
             fk_field_id=None, 
             parents=None
@@ -220,6 +226,7 @@ class QueryDropDownField(FieldElement, ReqInjectScriptMixin):
         self.field_name = field_name
         self.from_table = from_table
         self.where = where
+        self.order_by = order_by
         self.additional_where = additional_where
         self.dependents = []
             
@@ -256,12 +263,13 @@ class QueryDropDownField(FieldElement, ReqInjectScriptMixin):
     def _init_data_source(self):
         additional_where = self.additional_where or ''
         where = f'where {self.where} {additional_where}' if self.where else ''
+        order_by = f"order by {self.order_by}" if self.order_by else f"order by {self.field_name} asc"
         
         sql = (
             f"select {self.field_id} as id, {self.field_name} as name "
             f"from {self.from_table} "
             f"{where} "
-            f"order by {self.field_name} asc;"
+            f"{order_by}"
         )
         
         if self.dbname:
@@ -322,6 +330,7 @@ class QueryDropDownField(FieldElement, ReqInjectScriptMixin):
     def data(self, value):
         # reset ui
         value = value if value else self.form_data
+        self._data = value
         options = []
         if self.choices:
             # validate if choices are a list of tuple
@@ -361,6 +370,7 @@ class TextField(FieldElement):
             raise ValueError(f'{self.name} must be a string!')
         self.attrs.append(('value', value))
         self.input.attrs.append(('value', value))
+        self._data = value
         
 class TextAreaField(FieldElement):
     rows = ValidProp(int)
@@ -389,6 +399,7 @@ class TextAreaField(FieldElement):
         if value is not None and not isinstance(value, str):
             raise ValueError(f'{self.name} must be a string!')
         self.input.inner_text = value
+        self._data = value
         
 class TextAreaSummernoteField(FieldElement, ReqInjectScriptMixin):
     rows = ValidProp(int)
@@ -418,6 +429,7 @@ class TextAreaSummernoteField(FieldElement, ReqInjectScriptMixin):
         if value is not None and not isinstance(value, str):
             raise ValueError(f'{self.name} must be a string!')
         self.input.inner_text = value
+        self._data = value
         
 class UploadField(FieldElement):
     def __init__(self, name, required=False, disabled=False, readonly=False, placeholder=None, validators=None):
