@@ -31,7 +31,7 @@ class Message(Element):
         msg_box.append_inner(msg_content)
         
         if self.has_segment:
-            segment = Segment(msg_box, opt_css_class='basic')
+            segment = Segment(msg_box, opt_css_class='horizontally fitted basic')
             self.append_inner(segment)
         else:
             self.append_inner(msg_box)
