@@ -8,7 +8,7 @@ class SideBar(Element, ReqInjectScriptMixin):
         super().__init__('')
         self.sidebar_menu = Menu(css_class='ui sidebar inverted vertical menu', hide_id=False)
         self.content = Element('div', css_class='pusher')
-        self.nav_menu = Menu(css_class='ui primary inverted large menu custom')
+        self.nav_menu = Menu(css_class='ui primary inverted large stackable menu custom')
         self.toggle = MenuItem('', '', icon=Icon('bars icon'), hide_id=False)
         self.nav_menu.append_inner(self.toggle)
         # combined
