@@ -424,7 +424,7 @@ class Table(CoreElement, ReqInjectScriptMixin):
             fp = item.get(colitem.fp_col_name)
             if fp:
                 url = url_for('static', filename=fp.replace('static/', ''))
-                output = A(text=data, url=url).get_html()
+                output = A(text=data, url=url, target='_blank').get_html()
             else:
                 output = str(data)
         return output
